package com.loafle.rpc.api;

import com.fasterxml.jackson.core.JsonProcessingException;
import com.googlecode.jsonrpc4j.spring.AutoJsonRpcServiceImpl;
import com.loafle.rpc.crawler.Crawler;
import com.loafle.rpc.model.Input;
import com.loafle.rpc.model.Output;
import org.springframework.stereotype.Service;

import java.util.Date;
import java.util.HashMap;
import java.util.Map;

@Service
@AutoJsonRpcServiceImpl
public class RemoteImpl implements Remote {

    private Map<String, Crawler> crawlerMap = null;


    @Override
    public Output init(Input input) throws JsonProcessingException {

        for (String v : input.getPaths()) {
            System.out.println(v);
        }
        Output out = new Output();
        out.setStartDate(new Date());
        out.setEndDate(new Date());
        out.setData("Method init".getBytes());
        return out;
    }

    @Override
    public Output add(Input input) throws JsonProcessingException {
        Crawler crawler = this.crawlerMap.get(input.getName());
        if(crawler == null) {
            System.out.println(input.getName() + "_crawler == null");
            return null;
        } else {
            return crawler.add(input.getId());
        }
    }

    @Override
    public int addDelegate(String name, Crawler crawler) {

        if(this.crawlerMap == null) {
            this.crawlerMap = new HashMap<String, Crawler>();
        }

        if(this.crawlerMap.containsKey(name)) {
            return 1;
        }

        this.crawlerMap.put(name, crawler);

        return 0;
    }

    @Override
    public Output get(Input input) throws JsonProcessingException {

        Crawler crawler = this.crawlerMap.get(input.getName());
        if(crawler == null) {
            System.out.println(input.getName() + "_crawler == null");
            return null;
        } else {
            return crawler.get(input.getId());
        }

    }

    @Override
    public Output remove(Input input) throws JsonProcessingException {
        Crawler crawler = this.crawlerMap.get(input.getName());
        if(crawler == null) {
            System.out.println(input.getName() + "_crawler == null");
            return null;
        } else {
            return crawler.remove(input.getId());
        }
    }
}